@@ -2,6 +2,7 @@ import logging
 
 from sqlalchemy import Column, BigInteger
 from sqlalchemy import Integer
+from sqlalchemy import String
 from vortex.Tuple import Tuple, addTupleType
 
 from peek_abstract_chunked_index.private.tuples.ACIProcessorQueueTupleABC import (
@@ -14,12 +15,14 @@ logger = logging.getLogger(__name__)
 
 
 @addTupleType
-class SearchIndexCompilerQueue(Tuple, DeclarativeBase, ACIProcessorQueueTupleABC):
+class SearchIndexCompilerQueue(
+    Tuple, DeclarativeBase, ACIProcessorQueueTupleABC
+):
     __tablename__ = "SearchIndexCompilerQueue"
     __tupleType__ = searchTuplePrefix + "SearchIndexCompilerQueueTable"
 
     id = Column(BigInteger, primary_key=True, autoincrement=True)
-    chunkKey = Column(Integer, primary_key=True)
+    chunkKey = Column(String, primary_key=True)
 
     @classmethod
     def sqlCoreLoad(cls, row):
